<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="175"/>
        <source>License</source>
        <translation>라이센스</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>색상을 변경하려면 클릭하십시오.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>색상 선택</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation>FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>다음 (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>이전 (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>검색...</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>이름으로만 검색 (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation>Ctrl+Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>태그에서만 검색 (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation>Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>모든 노드에서 검색 (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>전체 단어 (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>전체 단어</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>대소문자 구분 (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>대소문자 구분</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>파일(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>최근에 열림(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>편집(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>형식(&amp;M)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>트리(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>옵션(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>검색(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>도움말(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>찾기:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>다음으로 교체:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>교체 예정</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>텍스트 바꾸기</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>이전 (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>다음 (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation>F8</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>모두 바꾸기 (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>저장(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1031"/>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="691"/>
        <source>&amp;Open</source>
        <translation>열기(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>실행 취소(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>실행 취소</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>다시 실행(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>다시 실행</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>찾기(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>검색 창 표시/숨김</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>모든 형식 지우기(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>모든 형식 지우기</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>굵게(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>굵게</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>기울임꼴(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>기울임꼴</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>밑줄(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>밑줄</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>취소선(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>취소선</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>텍스트 색상(&amp;X)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>텍스트 색상</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation>Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>배경색(&amp;G)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>배경색</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation>Alt+Shift+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="690"/>
        <source>&amp;New Note</source>
        <translation>새 노트(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation>Ctrl+Alt+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>다른 이름으로 저장(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>인쇄(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>하위 노드로 인쇄(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>암호 설정(&amp;W)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="693"/>
        <source>&amp;Quit</source>
        <translation>종료(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>잘라내기(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>복사하기(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>붙여넣기(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>삭제하기(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>전체 선택(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>이미지 삽입(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4378"/>
        <source>Embed Image</source>
        <translation>이미지 끼워넣기</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation>Ctrl+Alt+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>모두 펼치기(&amp;X)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>모두 축소(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>형제 추가(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>자녀 추가(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>노드 삭제(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>위로 이동(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>아래로 이동(&amp;W)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation>Alt+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>노드 이름 변경(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>트리 속성(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>문서 글꼴(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>줄 바꿈(&amp;W)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>자동-들여쓰기(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>기본 설정(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>찾기 및 바꾸기(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>소개(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>모든 노드 인쇄(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>슈퍼스크립트(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>슈퍼스크립트</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation>Alt+Shift+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>구독(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>구독</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation>Alt+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>중앙(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>중앙 정렬</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation>Alt+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2176"/>
        <source>&amp;Right</source>
        <translation>오른쪽(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>오른쪽 정렬</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Shift+Right</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2170"/>
        <source>&amp;Left</source>
        <translation>왼쪽(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>왼쪽 정렬</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Shift+Left</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>양쪽(&amp;J)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>양쪽</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation>Alt+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>형제 앞에 추가(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>왼쪽으로 이동(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>오른쪽으로 이동(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation>Alt+Right</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation>h&amp;2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>머리글 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation>h&amp;1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>머리글 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation>h&amp;3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>머리글 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>노드 글꼴(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>노드 글꼴</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>이미지 크기조정(&amp;M)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>HTML 붙여넣기(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>태그(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation>Ctrl+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>Link 삽입(&amp;K)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>링크 복사(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>표 삽입(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation>Ctrl+Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>행 추가</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>행 삭제</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>열 추가</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>열 삭제</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>셀 병합</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>행 앞에 추가</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>열 앞에 추가</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>HTML 내보내기(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>이미지 저장(&amp;G)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>RTL</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Shift+Left</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>LTR</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Shift+Right</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>메뉴</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>노드 아이콘(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>맞춤법 검사</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>문서 색상(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>날짜 및 시간 붙여넣기</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>지우기(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2963"/>
        <source>Node Icon</source>
        <translation>노드 아이콘</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="675"/>
        <source>&amp;Raise/Hide</source>
        <translation>올리기/숨기기(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="927"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;새 메모입니까?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="928"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;이 문서를 그대로 두고&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;빈 문서를 만드시겠습니까?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="931"/>
        <location filename="../../fn.cpp" line="2794"/>
        <location filename="../../fn.cpp" line="4741"/>
        <source>Yes</source>
        <translation>예</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="932"/>
        <location filename="../../fn.cpp" line="2795"/>
        <location filename="../../fn.cpp" line="4742"/>
        <source>No</source>
        <translation>아니오</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1023"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;변경사항을 저장하시겠습니까?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1025"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;문서가 수정되었습니다.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1027"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;문서가 제거되었습니다. &lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1032"/>
        <source>Discard changes</source>
        <translation>변경 내용 삭제</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1033"/>
        <location filename="../../fn.cpp" line="2912"/>
        <location filename="../../fn.cpp" line="3006"/>
        <location filename="../../fn.cpp" line="3279"/>
        <location filename="../../fn.cpp" line="4317"/>
        <location filename="../../fn.cpp" line="4402"/>
        <location filename="../../fn.cpp" line="4580"/>
        <location filename="../../fn.cpp" line="4843"/>
        <location filename="../../fn.cpp" line="5796"/>
        <location filename="../../fn.cpp" line="6075"/>
        <location filename="../../fn.cpp" line="6173"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1443"/>
        <source>Open file...</source>
        <translation>파일 열기...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1620"/>
        <location filename="../../fn.cpp" line="5922"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;저장할 수 없습니다!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3575"/>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1720"/>
        <location filename="../../fn.cpp" line="1743"/>
        <source>Save As...</source>
        <translation>다른 이름으로 저장...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <source>FeatherNotes documents</source>
        <translation>FeatherNotes 문서</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>All Files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2791"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;이 노드를 삭제하시겠습니까?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2792"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;경고!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;이 작업은 취소할 수 없습니다.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2898"/>
        <source>Tags</source>
        <translation>태그</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2913"/>
        <location filename="../../fn.cpp" line="3007"/>
        <location filename="../../fn.cpp" line="3280"/>
        <location filename="../../fn.cpp" line="4319"/>
        <location filename="../../fn.cpp" line="4403"/>
        <location filename="../../fn.cpp" line="4581"/>
        <location filename="../../fn.cpp" line="4844"/>
        <location filename="../../fn.cpp" line="5798"/>
        <location filename="../../fn.cpp" line="6076"/>
        <location filename="../../fn.cpp" line="6174"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>Image Files</source>
        <translation>이미지 파일</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3087"/>
        <location filename="../../fn.cpp" line="3120"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;기본 노드:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;모든 노드:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3093"/>
        <location filename="../../fn.cpp" line="3126"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;노트:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;주요 노드:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;전체 노드:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3562"/>
        <source>%1 Matches</source>
        <translation>%1개 일치</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3564"/>
        <source>One Match</source>
        <translation>한 개 일치</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3566"/>
        <location filename="../../fn.cpp" line="3933"/>
        <source>No Match</source>
        <translation>일치 안함</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3732"/>
        <location filename="../../fn.cpp" line="3785"/>
        <source>Replacement</source>
        <translation>대체</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4040"/>
        <source>No Replacement</source>
        <translation>대체 안함</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4042"/>
        <source>One Replacement</source>
        <translation>한 개 대체</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4045"/>
        <source>%1 Replacements</source>
        <translation>%1개 교체</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4305"/>
        <source>Insert Link</source>
        <translation>링크 삽입</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6019"/>
        <source>HTML Files</source>
        <translation>HTML 파일</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2971"/>
        <location filename="../../fn.cpp" line="4387"/>
        <source>Image path</source>
        <translation>이미지 경로</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2975"/>
        <location filename="../../fn.cpp" line="4391"/>
        <source>Open image</source>
        <translation>이미지 열기</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4399"/>
        <location filename="../../fn.cpp" line="4577"/>
        <source>Scaling percentage</source>
        <translation>배율</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2993"/>
        <location filename="../../fn.cpp" line="4499"/>
        <source>Open Image...</source>
        <translation>이미지 열기...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="652"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>시스템 트레이를 사용할 수 없습니다.
환경 설정에서 트레이를 비활성화하세요.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="978"/>
        <source>New Node</source>
        <translation>새 노드</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1621"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;열 수 없습니다!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1702"/>
        <location filename="../../fn.cpp" line="5637"/>
        <location filename="../../fn.cpp" line="5646"/>
        <location filename="../../fn.cpp" line="5785"/>
        <location filename="../../fn.cpp" line="5976"/>
        <location filename="../../fn.cpp" line="5985"/>
        <location filename="../../fn.cpp" line="6012"/>
        <source>Untitled</source>
        <translation>제목 없음</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2169"/>
        <source>Align Table</source>
        <translation>표 정렬</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2182"/>
        <source>&amp;Center</source>
        <translation>중앙(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2621"/>
        <source>Select Text Color</source>
        <translation>텍스트 색상 선택</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2653"/>
        <source>Select Background Color</source>
        <translation>배경색 선택</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2790"/>
        <source>Deletion</source>
        <translation>삭제</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2908"/>
        <source>Tag(s) for this node</source>
        <translation>이 노드에 대한 태그</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3164"/>
        <source>Select Document Font</source>
        <translation>문서 글꼴 선택</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3226"/>
        <source>Select Node Font</source>
        <translation>노드 글꼴 선택</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3251"/>
        <source>Set Document Colors</source>
        <translation>문서 색상 설정</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3261"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>이 색상은 새 노드에 적용됩니다.&lt;br&gt;기존 노드에 영향을 미칠 수도 있고 그렇지 &lt;br&gt;않을 수도 있지만 문서를 다시 여는 것이 좋습니다.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3264"/>
        <source>Background color:</source>
        <translation>배경색:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3270"/>
        <source>Text color:</source>
        <translation>텍스트 색상:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4050"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>처음 1000개의 대체 항목이 강조 표시됩니다.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4394"/>
        <location filename="../../fn.cpp" line="4573"/>
        <source>Scale to</source>
        <translation>다음으로 확장</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4398"/>
        <location filename="../../fn.cpp" line="4576"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4567"/>
        <source>Scale Image(s)</source>
        <translation>이미지 크기조정</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4704"/>
        <source>untitled</source>
        <translation>제목 없음</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4736"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4737"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;이미지를 저장할 수 없습니다! 다시 시도하시겠습니까?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4738"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;적절한 확장자를 선택하지 않았거나&lt;/center&gt;
&lt;center&gt;쓰기 권한이 없을 수 있습니다.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4770"/>
        <source>Save Image As...</source>
        <translation>다른 이름으로 이미지 저장 ...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4825"/>
        <source>Insert Table</source>
        <translation>표 삽입</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4831"/>
        <source>Rows:</source>
        <translation>행:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4837"/>
        <source>Columns:</source>
        <translation>열:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5726"/>
        <source>Print Document</source>
        <translation>문서 인쇄</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5732"/>
        <source>Printing completed.</source>
        <translation>인쇄가 완료되었습니다.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5734"/>
        <source>Printing in progress...</source>
        <translation>진행 중인 인쇄...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5753"/>
        <source>Export HTML</source>
        <translation>HTML 내보내기</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5758"/>
        <source>Export:</source>
        <translation>내보내기:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5759"/>
        <source>&amp;Current node</source>
        <translation>현재 노드(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5761"/>
        <source>With all &amp;sub-nodes</source>
        <translation>모든 하위 노드 포함(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5762"/>
        <source>&amp;All nodes</source>
        <translation>모든 노드(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5774"/>
        <source>Output file:</source>
        <translation>출력 파일:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5793"/>
        <source>Select path</source>
        <translation>경로 선택</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5834"/>
        <source>Question</source>
        <translation>질문</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5835"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>파일이 이미 있습니다.
교체 하시겠습니까?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6017"/>
        <source>Save HTML As...</source>
        <translation>다른 이름으로 HTML 저장 ...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6043"/>
        <source>Set Password</source>
        <translation>비밀번호 설정</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6052"/>
        <source>Type password</source>
        <translation>비밀번호 입력</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6064"/>
        <source>Retype password</source>
        <translation>비밀번호 재 입력</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6136"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;비밀번호가 다릅니다. 다시 시도하세요!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6156"/>
        <location filename="../../fn.cpp" line="6164"/>
        <source>Enter Password</source>
        <translation>비밀번호 입력</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6236"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;잘못된 비밀번호 입니다. 다시 시도하세요!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6275"/>
        <source>A lightweight notes manager</source>
        <translation>가벼운 메모 관리자</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6276"/>
        <source>based on Qt</source>
        <translation>Qt기반으로 작성됨</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6277"/>
        <source>Author</source>
        <translation>작성자</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <location filename="../../fn.cpp" line="6280"/>
        <source>About FeatherNotes</source>
        <translation>FeatherNotes 정보</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <source>Translators</source>
        <translation>번역자</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6463"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>기본 설정 → 텍스트 → 맞춤법 검사를 참조하십시오!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6479"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Hunspell 사전을 추가해야합니다.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6484"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>Hunspell 사전이 없습니다.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6492"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>Hunspell 사전에는 접사 파일이 포함되어 있지 않습니다.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6510"/>
        <location filename="../../fn.cpp" line="6525"/>
        <location filename="../../fn.cpp" line="6537"/>
        <source>No misspelling from text cursor.</source>
        <translation>텍스트 커서에서 맞춤법 오류가 없습니다.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6549"/>
        <source>Spell Checking</source>
        <translation>맞춤법 검사</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6278"/>
        <source>aka.</source>
        <translation>별명.</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>텍스트 지우기 (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation>Ctrl+K</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>기본 설정</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>이 대화상자를 닫은 후 종료시
창 크기를 저장합니다.

고정 크기를 설정하려면 선택을 취소하십시오!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>창 크기 기억(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>이 크기로 시작: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> 픽셀</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>이 대화상자를 닫고 종료할 때도
트리 너비를 저장합니다.

너비 비율이 170/530이면 선택을 취소합니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>트리 너비 기억(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>닫기 후 위치 저장
이 대화 상자 및 나갈 때도 포함합니다.

일부 창 관리자에서는 
제대로 작동하지 않을 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>위치 저장(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>시스템 트레이 아이콘을 사용할지 여부를 결정합니다.
선택하면 제목 표시줄 닫기 버튼이 창을 종료하는
대신 시스템 트레이에 아이콘으로 표시합니다.

적용하려면 FeatherNotes를 다시 시작해야 합니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>시스템 트레이에 추가(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>명령 줄 옵션 --tray
를 대신 사용할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>트레이에 아이콘화된 시작(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>트리 보기를 주변 환경과 병합하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>투명한 트리 보기(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>기본적으로 활성 위젯 스타일은 도구 모음
아이콘의 크기를 결정합니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>작은 도구 모음 아이콘</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>도구 모음 표시 안함(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>메뉴 표시줄이 숨겨져 있으면,
도구 모음에 메뉴 버튼이 나타납니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>메뉴 표시줄 표시 안함(&amp;M)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>기본적으로 줄 바꿈(&amp;W)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>기본적으로 자동 들여 쓰기(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>여기에는 괄호, 중괄호, 대괄호 및 따옴표가 포함됩니다.

FeatherNotes를 다시 시작해야 적용됩니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>자동 대괄호(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>사용자가 적절한 상황에서 입력하는 동안,
세 개의 마침표는 줄임표, 긴 대시가 있는
이중 하이픈 등으로 대체됩니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>입력하는 동안 일부 문자 바꾸기(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>날짜 및 시간을 붙여넣는 데 사용됩니다.
시스템 기본값을 사용하려면 비워 두십시오.

이 대화창을 닫은 후에 적용됩니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>날짜 및 시간 형식:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>자동 저장 간격(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> 분</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>이 옵션을 선택하면 열린 문서가
프롬프트 없이 나갈 때 저장됩니다.
저장할 수 없는 경우 경고를 표시합니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>나갈 때 열린 문서 저장하기</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>맞춤법 검사</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Hunspell 사전에는 &quot;.dic&quot;로 끝나는 이름이 있으며
이름은 같지만 &quot;.aff&quot;로 끝나는 접사 파일과
함께 있어야 합니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Hunspell 사전 경로 :</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="653"/>
        <source>Add dictionary...</source>
        <translation>사전 추가...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>마지막으로 열린 파일로 시작</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>최근 파일 수 :</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>최근 파일 개별적으로 열기</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>기본적으로, 모든 노드는 문서를 열 때 확장됩니다.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>노드의 확장 상태 기억</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>단축키</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>동작</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>단축키</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>기본값</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="346"/>
        <location filename="../../pref.cpp" line="526"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>경고: 모호한 단축키가 감지되었습니다!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="509"/>
        <source>The typed shortcut was reserved.</source>
        <translation>입력한 단축키가 예약되었습니다.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="624"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>변경 사항을 적용하려면 응용 프로그램을 다시 시작해야 합니다.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="655"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Hunspell 사전 파일</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>알 수 없는 단어:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>사전에 추가</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>다음으로 교체:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>한 번 무시</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>모두 무시</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>한 번 정정</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>모두 정정</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="101"/>
        <location filename="../../domitem.cpp" line="103"/>
        <location filename="../../domitem.cpp" line="142"/>
        <location filename="../../domitem.cpp" line="144"/>
        <source>New Node</source>
        <translation>새 노드</translation>
    </message>
</context>
</TS>
